<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>AppChooserDialog</name>
    <message>
        <location filename="../app-chooser-dialog.ui" line="14"/>
        <source>Choose an Application</source>
        <translation>選擇一個應用程式</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="36"/>
        <source>Installed Applications</source>
        <translation>安裝的應用程式</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="46"/>
        <source>Custom Command</source>
        <translation>自訂指令</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="52"/>
        <source>Command line to execute:</source>
        <translation>要執行的命令列:</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="62"/>
        <source>Application name:</source>
        <translation>應用程式名稱:</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="72"/>
        <source>&lt;b&gt;These special codes can be used in the command line:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: Represents a single file name&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: Represents multiple file names&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: Represents a single URI of the file&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: Represents multiple URIs&lt;/li&gt;
&lt;/ul&gt;</source>
        <translation>&lt;b&gt;這些特殊代號可以在指令列參數使用：&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;：代表單一檔案名稱&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;：代表多個檔案名稱&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;：代表單一檔案 URI&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;：代表多個 URI&lt;/li&gt;
&lt;/ul&gt;</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="91"/>
        <source>Keep terminal window open after command execution</source>
        <translation>執行指令後保持終端機視窗開啟</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="98"/>
        <source>Execute in terminal emulator</source>
        <translation>在終端機模擬器執行</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="109"/>
        <source>Set selected application as default action of this file type</source>
        <translation>將所選應用程式設定為此類型檔案的預設處理程式</translation>
    </message>
</context>
<context>
    <name>EditBookmarksDialog</name>
    <message>
        <location filename="../edit-bookmarks.ui" line="14"/>
        <source>Edit Bookmarks</source>
        <translation>編輯書籤</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="42"/>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="47"/>
        <source>Location</source>
        <translation>位置</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="67"/>
        <source>&amp;Add Item</source>
        <translation>新增項目(&amp;A)</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="77"/>
        <source>&amp;Remove Item</source>
        <translation>移除項目(&amp;R)</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="102"/>
        <source>Use drag and drop to reorder the items</source>
        <translation>使用拖放重新排序項目</translation>
    </message>
</context>
<context>
    <name>ExecFileDialog</name>
    <message>
        <location filename="../exec-file.ui" line="14"/>
        <source>Execute file</source>
        <translation>執行檔案</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="39"/>
        <source>&amp;Open</source>
        <translation>開啟(&amp;O)</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="52"/>
        <source>E&amp;xecute</source>
        <translation>執行(&amp;X)</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="62"/>
        <source>Execute in &amp;Terminal</source>
        <translation>在終端機內執行(&amp;T)</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="85"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>FileDialog</name>
    <message>
        <location filename="../filedialog.ui" line="22"/>
        <source>Path:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filedialog.ui" line="65"/>
        <source>File name:</source>
        <translation>檔案名稱:</translation>
    </message>
    <message>
        <location filename="../filedialog.ui" line="75"/>
        <source>File type:</source>
        <translation>檔案類型:</translation>
    </message>
</context>
<context>
    <name>FileOperationDialog</name>
    <message>
        <location filename="../file-operation-dialog.ui" line="32"/>
        <source>Destination:</source>
        <translation>目的地:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="55"/>
        <source>Processing:</source>
        <translation>正在處理:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="68"/>
        <source>Preparing...</source>
        <translation>準備中...</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="75"/>
        <source>Progress</source>
        <translation>進度</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="95"/>
        <source>Time remaining:</source>
        <translation>剩餘時間:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="125"/>
        <source>Files processed:</source>
        <translation>已處理的檔案:</translation>
    </message>
</context>
<context>
    <name>FilePropsDialog</name>
    <message>
        <location filename="../file-props.ui" line="14"/>
        <source>File Properties</source>
        <translation>檔案屬性</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="41"/>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="80"/>
        <source>Location:</source>
        <translation>位置:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="106"/>
        <source>File type:</source>
        <translation>檔案類型:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="129"/>
        <source>MIME type:</source>
        <translation>Mime 類型:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="152"/>
        <source>File size:</source>
        <translation>檔案大小:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="175"/>
        <source>On-disk size:</source>
        <translation>磁碟上大小:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="198"/>
        <source>Last modified:</source>
        <translation>最後修改:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="221"/>
        <source>Link target:</source>
        <translation>連結目標:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="247"/>
        <source>Open With:</source>
        <translation>開啟:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="264"/>
        <source>Last accessed:</source>
        <translation>最後存取:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="281"/>
        <source>Contains:</source>
        <translation>包含:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="336"/>
        <source>Device Usage:</source>
        <translation>裝置使用率:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="346"/>
        <source>Permissions</source>
        <translation>權限</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="361"/>
        <source>Ownership</source>
        <translation>所有權</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="385"/>
        <location filename="../file-props.ui" line="450"/>
        <location filename="../file-props.ui" line="564"/>
        <source>Group:</source>
        <translation>群組:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="398"/>
        <location filename="../file-props.ui" line="433"/>
        <location filename="../file-props.ui" line="512"/>
        <source>Owner:</source>
        <translation>擁有者:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="414"/>
        <source>Access Control</source>
        <translation>存取控制</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="467"/>
        <location filename="../file-props.ui" line="616"/>
        <source>Other:</source>
        <translation>其他:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="484"/>
        <source>Make the file executable</source>
        <translation>使檔案可執行</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="525"/>
        <location filename="../file-props.ui" line="577"/>
        <location filename="../file-props.ui" line="629"/>
        <source>Read</source>
        <translation>讀取</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="538"/>
        <location filename="../file-props.ui" line="590"/>
        <location filename="../file-props.ui" line="642"/>
        <source>Write</source>
        <translation>寫入</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="551"/>
        <location filename="../file-props.ui" line="603"/>
        <location filename="../file-props.ui" line="655"/>
        <source>Execute</source>
        <translation>執行</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="664"/>
        <source>Sticky</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="671"/>
        <source>SetUID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="678"/>
        <source>SetGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="714"/>
        <source>Advanced Mode</source>
        <translation>進階模式</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserComboBox</name>
    <message>
        <location filename="../appchoosercombobox.cpp" line="66"/>
        <source>Customize</source>
        <translation>自訂</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserDialog</name>
    <message>
        <location filename="../appchooserdialog.cpp" line="263"/>
        <source>Select an application to open &quot;%1&quot; files</source>
        <translation>選取用來開啟「%1」檔案的應用程式</translation>
    </message>
</context>
<context>
    <name>Fm::CreateNewMenu</name>
    <message>
        <location filename="../createnewmenu.cpp" line="62"/>
        <source>Folder</source>
        <translation>資料夾</translation>
    </message>
    <message>
        <location filename="../createnewmenu.cpp" line="66"/>
        <source>Blank File</source>
        <translation>空白檔案</translation>
    </message>
</context>
<context>
    <name>Fm::DirListJob</name>
    <message>
        <location filename="../core/dirlistjob.cpp" line="48"/>
        <source>The specified directory &apos;%1&apos; is not valid</source>
        <translation>指定的目錄 &apos;%1&apos; 無效</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeModel</name>
    <message>
        <location filename="../dirtreemodelitem.cpp" line="84"/>
        <source>Loading...</source>
        <translation>載入中...</translation>
    </message>
    <message>
        <location filename="../dirtreemodelitem.cpp" line="267"/>
        <location filename="../dirtreemodelitem.cpp" line="311"/>
        <location filename="../dirtreemodelitem.cpp" line="409"/>
        <source>&lt;No sub folders&gt;</source>
        <translation>&lt;沒有子資料夾&gt;</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeView</name>
    <message>
        <location filename="../dirtreeview.cpp" line="213"/>
        <source>Open in New T&amp;ab</source>
        <translation>在新分頁開啟 (&amp;A)</translation>
    </message>
    <message>
        <location filename="../dirtreeview.cpp" line="217"/>
        <source>Open in New Win&amp;dow</source>
        <translation>在新視窗開啟 (&amp;D)</translation>
    </message>
    <message>
        <location filename="../dirtreeview.cpp" line="222"/>
        <source>Open in Termina&amp;l</source>
        <translation>在終端機內開啟 (&amp;I)</translation>
    </message>
</context>
<context>
    <name>Fm::DndActionMenu</name>
    <message>
        <location filename="../dndactionmenu.cpp" line="32"/>
        <source>Copy here</source>
        <translation>複製到這裡</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="35"/>
        <source>Move here</source>
        <translation>移動到這裡</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="38"/>
        <source>Create symlink here</source>
        <translation>建立符號連結到這裡</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="41"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>Fm::EditBookmarksDialog</name>
    <message>
        <location filename="../editbookmarksdialog.cpp" line="84"/>
        <source>New bookmark</source>
        <translation>新書籤</translation>
    </message>
</context>
<context>
    <name>Fm::ExecFileDialog</name>
    <message>
        <location filename="../execfiledialog.cpp" line="40"/>
        <source>This file &apos;%1&apos; seems to be a desktop entry.
What do you want to do with it?</source>
        <translation>檔案 &apos;%1&apos; 看起來是桌面捷徑檔。
你想要對它進行什麼操作?</translation>
    </message>
    <message>
        <location filename="../execfiledialog.cpp" line="46"/>
        <source>This text file &apos;%1&apos; seems to be an executable script.
What do you want to do with it?</source>
        <translation>這個文字檔 &apos;%1&apos; 似乎是可執行的 script。
想要進行什麼操作？</translation>
    </message>
    <message>
        <location filename="../execfiledialog.cpp" line="51"/>
        <source>This file &apos;%1&apos; is executable. Do you want to execute it?</source>
        <translation>這個檔案 &apos;%1&apos; 是可執行檔，是否想要執行？</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialog</name>
    <message>
        <location filename="../filedialog.cpp" line="109"/>
        <source>Go Back</source>
        <translation>上一頁</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="110"/>
        <source>Alt+Left</source>
        <comment>Go Back</comment>
        <translation>Alt+Left</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="116"/>
        <source>Go Forward</source>
        <translation>下一頁</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="117"/>
        <source>Alt+Right</source>
        <comment>Go Forward</comment>
        <translation>Alt+Right</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="124"/>
        <source>Reload</source>
        <translation>重新整理</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="125"/>
        <source>F5</source>
        <comment>Reload</comment>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="142"/>
        <source>Create Folder</source>
        <translation>建立資料夾</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="152"/>
        <source>Icon View</source>
        <translation>圖示檢視</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="156"/>
        <source>Thumbnail View</source>
        <translation>縮圖檢視</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="160"/>
        <source>Compact View</source>
        <translation>精簡檢視</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="164"/>
        <source>Detailed List View</source>
        <translation>詳細清單檢視</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="172"/>
        <source>Icon Sizes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="174"/>
        <source>Size of big icons:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="181"/>
        <source>Size of small icons:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="188"/>
        <source>Size of thumbnails:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="204"/>
        <source>Show Thumbnails</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="209"/>
        <source>Show File Tooltips</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="220"/>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="540"/>
        <location filename="../filedialog.cpp" line="935"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="540"/>
        <source>Please select a file</source>
        <translation>請選擇一個檔案</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="582"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 已經存在。
你想要取代它嗎?</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="905"/>
        <source>Path &quot;%1&quot; does not exist</source>
        <translation>路徑 &quot;%1&quot; 不存在</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="919"/>
        <source>&quot;%1&quot; is not a directory</source>
        <translation>&quot;%1&quot; 不是一個目錄</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="925"/>
        <source>&quot;%1&quot; is not a file</source>
        <translation>&quot;%1&quot; 不是一個檔案</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1077"/>
        <location filename="../filedialog.cpp" line="1185"/>
        <source>&amp;Open</source>
        <translation>開啟(&amp;O)</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1080"/>
        <location filename="../filedialog.cpp" line="1193"/>
        <source>&amp;Save</source>
        <translation>儲存 (&amp;S)</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1087"/>
        <source>All Files (*)</source>
        <translation>所有檔案 (*)</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialogHelper</name>
    <message>
        <location filename="../filedialoghelper.cpp" line="139"/>
        <source>Open File</source>
        <translation>開啟檔案</translation>
    </message>
    <message>
        <location filename="../filedialoghelper.cpp" line="140"/>
        <source>Save File</source>
        <translation>儲存檔案</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialogIconSizeAction</name>
    <message>
        <location filename="../filedialog_p.h" line="40"/>
        <source> px</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Fm::FileMenu</name>
    <message>
        <location filename="../filemenu.cpp" line="84"/>
        <source>Open</source>
        <translation>開啟</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="88"/>
        <source>Open With...</source>
        <translation>用其他程式開啟...</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="116"/>
        <source>Other Applications</source>
        <translation>其他應用程式</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="122"/>
        <source>Create &amp;New</source>
        <translation>新建(&amp;N)</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="141"/>
        <source>&amp;Restore</source>
        <translation>恢復(&amp;R)</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="147"/>
        <source>Cut</source>
        <translation>剪下</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="151"/>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="155"/>
        <source>Paste</source>
        <translation>貼上</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="159"/>
        <location filename="../filemenu.cpp" line="407"/>
        <source>&amp;Move to Trash</source>
        <translation>移動到垃圾桶(&amp;M)</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="253"/>
        <source>Trust selected executables</source>
        <translation>信任已選擇的執行檔</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="254"/>
        <source>Trust this executable</source>
        <translation>信任此執行檔</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="342"/>
        <source>Output</source>
        <translation>輸出</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="407"/>
        <source>&amp;Delete</source>
        <translation>刪除(&amp;D)</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="163"/>
        <source>Rename</source>
        <translation>重新命名</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="218"/>
        <source>Extract to...</source>
        <translation>解壓縮到...</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="226"/>
        <source>Extract Here</source>
        <translation>在此解壓縮</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="233"/>
        <source>Compress</source>
        <translation>壓縮</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="242"/>
        <source>Properties</source>
        <translation>屬性</translation>
    </message>
</context>
<context>
    <name>Fm::FileOperation</name>
    <message>
        <location filename="../fileoperation.cpp" line="312"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="313"/>
        <source>Some files cannot be moved to trash can because the underlying file systems don&apos;t support this operation.
Do you want to delete them instead?</source>
        <translation>因為檔案系統不支援，有些檔案無法丟到垃圾桶
是否直接刪除這些檔案？</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="399"/>
        <location filename="../fileoperation.cpp" line="417"/>
        <source>Confirm</source>
        <translation>確認</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="400"/>
        <source>Do you want to delete the selected files?</source>
        <translation>你確定要刪除選取的檔案嗎?</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="418"/>
        <source>Do you want to move the selected files to trash can?</source>
        <translation>你確定要把選取的檔案移到垃圾桶嗎?</translation>
    </message>
</context>
<context>
    <name>Fm::FileOperationDialog</name>
    <message>
        <location filename="../fileoperationdialog.cpp" line="46"/>
        <source>Move files</source>
        <translation>移動檔案</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="47"/>
        <source>Moving the following files to destination folder:</source>
        <translation>正在移動下列檔案到目的資料夾:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="50"/>
        <source>Copy Files</source>
        <translation>複製檔案</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="51"/>
        <source>Copying the following files to destination folder:</source>
        <translation>正在複製下列檔案到目的資料夾:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="54"/>
        <source>Trash Files</source>
        <translation>將檔案丟到垃圾桶</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="55"/>
        <source>Moving the following files to trash can:</source>
        <translation>正在將下列檔案移動到垃圾桶:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="58"/>
        <source>Delete Files</source>
        <translation>刪除檔案</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="59"/>
        <source>Deleting the following files:</source>
        <translation>正在刪除下列檔案:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="64"/>
        <source>Create Symlinks</source>
        <translation>建立符號連結</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="65"/>
        <source>Creating symlinks for the following files:</source>
        <translation>正在建立下列檔案的符號連結:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="68"/>
        <source>Change Attributes</source>
        <translation>改變屬性</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="69"/>
        <source>Changing attributes of the following files:</source>
        <translation>正在更改下列檔案的屬性:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="74"/>
        <source>Restore Trashed Files</source>
        <translation>恢復被刪除的檔案</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="75"/>
        <source>Restoring the following files from trash can:</source>
        <translation>正在從垃圾桶恢復下列被刪除的檔案：</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="146"/>
        <location filename="../fileoperationdialog.cpp" line="152"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
</context>
<context>
    <name>Fm::FilePropsDialog</name>
    <message>
        <location filename="../filepropsdialog.cpp" line="162"/>
        <source>View folder content</source>
        <translation>檢視資料夾內容</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="163"/>
        <source>View and modify folder content</source>
        <translation>檢視及修改資料夾內容</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="167"/>
        <source>Read</source>
        <translation>讀取</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="168"/>
        <source>Read and write</source>
        <translation>讀取及寫入</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="170"/>
        <source>Forbidden</source>
        <translation>禁止</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="287"/>
        <source>Files of different types</source>
        <translation>不同類型的檔案</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="310"/>
        <source>Multiple Files</source>
        <translation>多個檔案</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="336"/>
        <source>%p% used</source>
        <translation>%p%已使用</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="337"/>
        <source>%1 Free of %2</source>
        <translation>%2中%1未使用</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="382"/>
        <source>no file</source>
        <translation>無檔案</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="384"/>
        <source>one file</source>
        <translation>1個檔案</translation>
    </message>
    <message numerus="yes">
        <location filename="../filepropsdialog.cpp" line="386"/>
        <source>%Ln files</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="420"/>
        <source>Select an icon</source>
        <translation>選擇一個圖示</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="422"/>
        <source>Images (*.png *.xpm *.svg *.svgz )</source>
        <translation>影像檔 (*.png *.xpm *.svg *.svgz )</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="518"/>
        <source>Apply changes</source>
        <translation>套用變更</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="519"/>
        <source>Do you want to recursively apply these changes to all files and sub-folders?</source>
        <translation>你是否想將這些變更套用到所有子資料夾和其內的檔案?</translation>
    </message>
</context>
<context>
    <name>Fm::FileSearchDialog</name>
    <message>
        <location filename="../filesearchdialog.cpp" line="128"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../filesearchdialog.cpp" line="128"/>
        <source>You should add at least one directory to search.</source>
        <translation>你至少需要新增一個要搜尋的目錄。</translation>
    </message>
    <message>
        <location filename="../filesearchdialog.cpp" line="135"/>
        <source>Select a folder</source>
        <translation>選擇一個資料夾</translation>
    </message>
</context>
<context>
    <name>Fm::FileTransferJob</name>
    <message>
        <location filename="../core/filetransferjob.cpp" line="471"/>
        <source>Cannot copy a directory into itself!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../core/filetransferjob.cpp" line="522"/>
        <source>Cannot create a link on non-native filesystem</source>
        <translation>無法在非原生檔案系統上建立連結</translation>
    </message>
</context>
<context>
    <name>Fm::FolderMenu</name>
    <message>
        <location filename="../foldermenu.cpp" line="41"/>
        <source>Create &amp;New</source>
        <translation>新建(&amp;N)</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="48"/>
        <source>&amp;Paste</source>
        <translation>貼上(&amp;P)</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="54"/>
        <source>Select &amp;All</source>
        <translation>全選(&amp;A)</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="58"/>
        <source>Invert Selection</source>
        <translation>反向選取</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="64"/>
        <source>Sorting</source>
        <translation>排序</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="69"/>
        <source>Show Hidden</source>
        <translation>顯示隱藏檔</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="98"/>
        <source>Folder Pr&amp;operties</source>
        <translation>資料夾屬性(&amp;O)</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="141"/>
        <source>Output</source>
        <translation>輸出</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="163"/>
        <source>By File Name</source>
        <translation>依照檔名</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="164"/>
        <source>By Modification Time</source>
        <translation>依照修改時間</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="167"/>
        <source>By Deletion Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="170"/>
        <source>By File Size</source>
        <translation>依照檔案大小</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="171"/>
        <source>By File Type</source>
        <translation>依照檔案型態</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="172"/>
        <source>By File Owner</source>
        <translation>依照檔案所有者</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="173"/>
        <source>By File Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="179"/>
        <source>Ascending</source>
        <translation>升冪排列</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="184"/>
        <source>Descending</source>
        <translation>降冪排列</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="201"/>
        <source>Folder First</source>
        <translation>資料夾優先</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="209"/>
        <source>Hidden Last</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="217"/>
        <source>Case Sensitive</source>
        <translation>區分大小寫</translation>
    </message>
</context>
<context>
    <name>Fm::FolderModel</name>
    <message>
        <location filename="../foldermodel.cpp" line="303"/>
        <source>Location:</source>
        <translation type="unfinished">位置:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="306"/>
        <source>File type:</source>
        <translation type="unfinished">檔案類型:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="310"/>
        <source>File size:</source>
        <translation type="unfinished">檔案大小:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="314"/>
        <source>Last modified:</source>
        <translation type="unfinished">最後修改日期:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="315"/>
        <source>Last accessed:</source>
        <translation type="unfinished">最後存取日期:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="319"/>
        <source>Owner:</source>
        <translation type="unfinished">擁有者:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="320"/>
        <source>Group:</source>
        <translation type="unfinished">群組:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="384"/>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="387"/>
        <source>Type</source>
        <translation>類型</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="390"/>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="393"/>
        <source>Modified</source>
        <translation>修改</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="396"/>
        <source>Deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="399"/>
        <source>Owner</source>
        <translation>所有者</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="402"/>
        <source>Group</source>
        <translation>群組</translation>
    </message>
</context>
<context>
    <name>Fm::FolderViewTreeView</name>
    <message>
        <location filename="../folderview.cpp" line="373"/>
        <source>Auto-resize columns</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../folderview.cpp" line="390"/>
        <source>Visible Columns</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>粗體</translation>
    </message>
    <message>
        <location filename="../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>斜體</translation>
    </message>
</context>
<context>
    <name>Fm::MountOperationPasswordDialog</name>
    <message>
        <location filename="../mountoperationpassworddialog.cpp" line="40"/>
        <source>&amp;Connect</source>
        <translation>連接(&amp;C)</translation>
    </message>
</context>
<context>
    <name>Fm::PathBar</name>
    <message>
        <location filename="../pathbar.cpp" line="130"/>
        <source>&amp;Edit Path</source>
        <translation>編輯路徑 (&amp;E)</translation>
    </message>
    <message>
        <location filename="../pathbar.cpp" line="133"/>
        <source>&amp;Copy Path</source>
        <translation>複製路徑 (&amp;C)</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesModel</name>
    <message>
        <location filename="../placesmodel.cpp" line="47"/>
        <source>Places</source>
        <translation>位置</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="55"/>
        <source>Desktop</source>
        <translation>桌面</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="227"/>
        <source>Trash</source>
        <translation>垃圾桶</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="61"/>
        <source>Computer</source>
        <translation>電腦</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="69"/>
        <source>Applications</source>
        <translation>應用程式</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="78"/>
        <source>Network</source>
        <translation>網路</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="82"/>
        <source>Devices</source>
        <translation>裝置</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="136"/>
        <source>Bookmarks</source>
        <translation>書籤</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesView</name>
    <message>
        <location filename="../placesview.cpp" line="496"/>
        <source>Empty Trash</source>
        <translation>清空垃圾桶</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="481"/>
        <source>Open in New Tab</source>
        <translation>在新分頁中開啟</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="484"/>
        <source>Open in New Window</source>
        <translation>在新視窗中開啟</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="516"/>
        <location filename="../placesview.cpp" line="573"/>
        <source>Hide</source>
        <translation>隱藏</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="533"/>
        <source>Move Bookmark Up</source>
        <translation>往上移動書籤</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="538"/>
        <source>Move Bookmark Down</source>
        <translation>往下移動書籤</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="542"/>
        <source>Rename Bookmark</source>
        <translation>重新命名書籤</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="545"/>
        <source>Remove Bookmark</source>
        <translation>移除書籤</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="554"/>
        <location filename="../placesview.cpp" line="587"/>
        <source>Unmount</source>
        <translation>卸載</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="558"/>
        <source>Mount</source>
        <translation>掛載</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="564"/>
        <source>Eject</source>
        <translation>退出</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="599"/>
        <source>Show All Entries</source>
        <translation>顯示全部的項目</translation>
    </message>
</context>
<context>
    <name>Fm::RenameDialog</name>
    <message>
        <location filename="../renamedialog.cpp" line="58"/>
        <location filename="../renamedialog.cpp" line="77"/>
        <source>Type: %1
Size: %2
Modified: %3</source>
        <translation>類型: %1
大小: %2
最後修改: %3</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="64"/>
        <location filename="../renamedialog.cpp" line="83"/>
        <source>Type: %1
Modified: %2</source>
        <translation>類型: %1
最後修改: %2</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="96"/>
        <source>&amp;Overwrite</source>
        <translation>覆蓋(&amp;O)</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="98"/>
        <source>&amp;Rename</source>
        <translation>重新命名(&amp;R)</translation>
    </message>
</context>
<context>
    <name>Fm::SidePane</name>
    <message>
        <location filename="../sidepane.cpp" line="45"/>
        <source>Lists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sidepane.cpp" line="46"/>
        <source>Directory Tree</source>
        <translation>目錄樹</translation>
    </message>
</context>
<context>
    <name>Fm::UntrashJob</name>
    <message>
        <location filename="../core/untrashjob.cpp" line="35"/>
        <source>Cannot untrash file &apos;%s&apos;: original path not known</source>
        <translation>無法將檔案從垃圾桶復原 &apos;%s&apos;: 原來路徑未知</translation>
    </message>
</context>
<context>
    <name>MountOperationPasswordDialog</name>
    <message>
        <location filename="../mount-operation-password.ui" line="20"/>
        <source>Mount</source>
        <translation>掛載</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="48"/>
        <source>Connect &amp;anonymously</source>
        <translation>匿名連線(&amp;A)</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="58"/>
        <source>Connect as u&amp;ser:</source>
        <translation>以使用者帳號連線(&amp;S):</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="79"/>
        <source>&amp;Username:</source>
        <translation>使用者名稱(&amp;U):</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="102"/>
        <source>&amp;Password:</source>
        <translation>密碼(&amp;P):</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="112"/>
        <source>&amp;Domain:</source>
        <translation>域名(&amp;D):</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="127"/>
        <source>Forget password &amp;immediately</source>
        <translation>立刻忘記密碼(&amp;I)</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="137"/>
        <source>Remember password for &amp;this session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="147"/>
        <source>Remember &amp;forever</source>
        <translation>永遠記住密碼(&amp;F)</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../filelauncher.cpp" line="104"/>
        <location filename="../filepropsdialog.cpp" line="543"/>
        <location filename="../mountoperation.cpp" line="207"/>
        <location filename="../utilities.cpp" line="147"/>
        <location filename="../utilities.cpp" line="283"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="163"/>
        <source>Rename File</source>
        <translation>重新命名</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="164"/>
        <source>Please enter a new name:</source>
        <translation>請輸入一個新名稱:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="223"/>
        <source>Create Folder</source>
        <translation>建立資料夾</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="228"/>
        <source>Please enter a new file name:</source>
        <translation>請輸入一個新檔名:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="233"/>
        <source>Please enter a new folder name:</source>
        <translation>請輸入一個新資料夾名稱:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="234"/>
        <source>New folder</source>
        <translation>新資料夾</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="229"/>
        <source>New text file</source>
        <translation>新文字檔</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="239"/>
        <source>Enter a name for the new %1:</source>
        <translation>幫新的 %1 輸入一個名稱:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="224"/>
        <source>Create File</source>
        <translation>建立檔案</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="560"/>
        <source>Custom Icon Error</source>
        <translation>自訂圖示錯誤</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="41"/>
        <source>The path is not mounted.</source>
        <translation>這個路徑尚未掛載。</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="289"/>
        <source>Invalid desktop entry file: &apos;%1&apos;</source>
        <translation>無效的桌面捷徑檔: &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="325"/>
        <source>No default application is set to launch &apos;%1&apos;</source>
        <translation>沒有預設的應用程式來開啟 &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="366"/>
        <source>Cannot set working directory to &apos;%1&apos;: %2</source>
        <translation>無法將目前工作目錄設定為 &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <location filename="../placesmodelitem.cpp" line="123"/>
        <source>Identifier: </source>
        <translation>識別符號: </translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <location filename="../rename-dialog.ui" line="14"/>
        <source>Confirm to replace files</source>
        <translation>確認取代檔案</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="35"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;There is already a file with the same name in this location.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Do you want to replace the existing file?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;這個位置已經有一個同名的檔案&lt;/span&gt;&lt;/p&gt;&lt;p&gt;你要取代現有的檔案嗎?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="63"/>
        <source>with the following file?</source>
        <translation>用下列檔案?</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="122"/>
        <source>&amp;File name:</source>
        <translation>檔名(&amp;F):</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="137"/>
        <source>Apply this option to all existing files</source>
        <translation>套用這個選項到所有已存在的檔案</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../filesearch.ui" line="14"/>
        <source>Search Files</source>
        <translation>搜尋檔案</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="29"/>
        <source>Name/Location</source>
        <translation>名稱/位置</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="35"/>
        <source>File Name Patterns:</source>
        <translation>檔案名稱樣式:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="41"/>
        <source>*</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="55"/>
        <source>Use regular expression</source>
        <translation>使用正規表示式 (regexp)</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="68"/>
        <source>Places to Search:</source>
        <translation>要搜尋的地方:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="81"/>
        <source>&amp;Add</source>
        <translation>新增 (&amp;A)</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="93"/>
        <source>&amp;Remove</source>
        <translation>移除 (&amp;R)</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="129"/>
        <source>Search for hidden files</source>
        <translation>搜尋隱藏檔</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="140"/>
        <source>File Type</source>
        <translation>檔案型態</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="146"/>
        <source>Only search for files of following types:</source>
        <translation>只搜尋下列型態的檔案:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="152"/>
        <source>Text files</source>
        <translation>文字檔</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="159"/>
        <source>Image files</source>
        <translation>圖片檔</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="166"/>
        <source>Audio files</source>
        <translation>聲音檔</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="173"/>
        <source>Video files</source>
        <translation>影片檔</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="180"/>
        <source>Documents</source>
        <translation>文件</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="187"/>
        <source>Folders</source>
        <translation>資料夾</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="211"/>
        <source>Content</source>
        <translation>內容</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="217"/>
        <source>File contains:</source>
        <translation>檔案包含:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="233"/>
        <source>&amp;Use regular expression</source>
        <translation>使用正規表示式 (&amp;U)</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="260"/>
        <source>Properties</source>
        <translation>屬性</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="266"/>
        <source>File Size:</source>
        <translation>檔案大小:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="295"/>
        <source>Larger than:</source>
        <translation>大於:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="309"/>
        <location filename="../filesearch.ui" line="339"/>
        <source>Bytes</source>
        <translation>位元組</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="314"/>
        <location filename="../filesearch.ui" line="344"/>
        <source>KiB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="319"/>
        <location filename="../filesearch.ui" line="349"/>
        <source>MiB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="324"/>
        <location filename="../filesearch.ui" line="354"/>
        <source>GiB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="274"/>
        <source>Smaller than:</source>
        <translation>小於:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="48"/>
        <source>Case sensitive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="122"/>
        <source>Search in subdirectories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="226"/>
        <source>Case sensiti&amp;ve</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="370"/>
        <source>Last Modified Time:</source>
        <translation>最後修改時間:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="378"/>
        <source>Earlier than:</source>
        <translation>早於:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="385"/>
        <source>Later than:</source>
        <translation>晚於:</translation>
    </message>
</context>
</TS>
